==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/CONTRACTCLASSID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CONTRACTCLASSID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CONTRACTCLASSID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONTRACTCLASSCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="entity" type="{http://schemas.datastream.net/MP_fields}CODE4_Type" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CONTRACTCLASSID_Type", propOrder = {
    "contractclasscode",
    "organizationid",
    "description"
})
public class CONTRACTCLASSID_Type {

    @XmlElement(name = "CONTRACTCLASSCODE", required = true)
    protected String contractclasscode;
    @XmlElement(name = "ORGANIZATIONID")
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "DESCRIPTION")
    protected String description;
    @XmlAttribute(name = "entity")
    protected String entity;

    /**
     * Obtient la valeur de la propriété contractclasscode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCONTRACTCLASSCODE() {
        return contractclasscode;
    }

    /**
     * Définit la valeur de la propriété contractclasscode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCONTRACTCLASSCODE(String value) {
        this.contractclasscode = value;
    }

    /**
     * Obtient la valeur de la propriété organizationid.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Définit la valeur de la propriété organizationid.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

    /**
     * Obtient la valeur de la propriété entity.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEntity() {
        return entity;
    }

    /**
     * Définit la valeur de la propriété entity.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEntity(String value) {
        this.entity = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/CONTRACTCLASSID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CONTRACTCLASSID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CONTRACTCLASSID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONTRACTCLASSCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="entity" type="{http://schemas.datastream.net/MP_fields}CODE4_Type" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CONTRACTCLASSID_Type", propOrder = {
    "contractclasscode",
    "organizationid",
    "description"
})
public class CONTRACTCLASSID_Type {

    @XmlElement(name = "CONTRACTCLASSCODE", required = true)
    protected String contractclasscode;
    @XmlElement(name = "ORGANIZATIONID")
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "DESCRIPTION")
    protected String description;
    @XmlAttribute(name = "entity")
    protected String entity;

    /**
     * Gets the value of the contractclasscode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCONTRACTCLASSCODE() {
        return contractclasscode;
    }

    /**
     * Sets the value of the contractclasscode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCONTRACTCLASSCODE(String value) {
        this.contractclasscode = value;
    }

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

    /**
     * Gets the value of the entity property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEntity() {
        return entity;
    }

    /**
     * Sets the value of the entity property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEntity(String value) {
        this.entity = value;
    }

}
